@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_CRYPTO_GUI_DECRYPTVERIFYFILESWIZARD_H__
-#define __KLEOPATRA_CRYPTO_GUI_DECRYPTVERIFYFILESWIZARD_H__
+#pragma once
 
 #include <crypto/gui/wizard.h>
 
@@ -62,4 +61,3 @@ private:
 }
 }
 
-#endif /* __KLEOPATRA_CRYPTO_GUI_DECRYPTVERIFYFILESWIZARD_H__ */
