@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_UISERVER_VERIFYCHECKSUMSCOMMAND_H__
-#define __KLEOPATRA_UISERVER_VERIFYCHECKSUMSCOMMAND_H__
+#pragma once
 
 #include "assuancommand.h"
 
@@ -24,7 +23,7 @@ class VerifyChecksumsCommand : public QObject, public AssuanCommandMixin<VerifyC
     Q_OBJECT
 public:
     VerifyChecksumsCommand();
-    ~VerifyChecksumsCommand();
+    ~VerifyChecksumsCommand() override;
 
     static const char *staticName()
     {
@@ -52,4 +51,3 @@ private:
 
 #endif // QT_NO_DIRMODEL
 
-#endif /* __KLEOPATRA_UISERVER_VERIFYCHECKSUMSCOMMAND_H__ */
